@@ -35,16 +35,22 @@ predict.gstatModel <- function(object, predictionLocations, nmin = 10, nmax = 30
     ## target variable name: 
     variable = all.vars(object@regModel$formula)[1]
   }
-  if(any(class(object@regModel) %in% "rpart")){
+  if(any(class(object@regModel)=="rpart")){
     rp <- list(predict(object@regModel, predictionLocations))
+    variable = all.vars(attr(object@regModel$terms, "variables"))[1]
   }
-  if(any(class(object@regModel) %in% "randomForest")){
+  if(any(class(object@regModel)=="quantregForest")){
+    covs = attr(object@regModel$forest$ncat, "names")
+    rp <- list(predict(object@regModel, predictionLocations@data[,covs], quantile=.5)) 
+    variable = attr(object@regModel$y, "name")[1]
+  }
+  if(any(class(object@regModel)=="randomForest")&!any(class(object@regModel)=="quantregForest")){
     rp <- list(predict(object@regModel, predictionLocations, type="response"))
+    variable = all.vars(attr(object@regModel$terms, "variables"))[1]
   }  
   ## rename the target variable:   
   if(any(class(object@regModel) %in% c("randomForest", "rpart"))){
     names(rp)[1] = "fit"
-    variable = all.vars(attr(object@regModel$terms, "variables"))[1]
   }
        
   ## vgm for residuals:
@@ -160,8 +166,10 @@ predict.gstatModel <- function(object, predictionLocations, nmin = 10, nmax = 30
         }
         ## mask out values outside physical limits:
         rk@data[,variable] <- ifelse(rk$var1.pred > zmax, zmax, ifelse(rk$var1.pred < zmin, zmin, rk$var1.pred))
-        if(object@regModel$family$family == "poisson"){
-          rk@data[,variable] <- as.integer(round(rk@data[,variable], 0))
+        if(any(class(object@regModel)=="glm")){
+          if(object@regModel$family$family == "poisson"){
+            rk@data[,variable] <- as.integer(round(rk@data[,variable], 0))
+          }
         }
         
         ## cross-validation (default implementation by gstat):
@@ -185,8 +193,10 @@ predict.gstatModel <- function(object, predictionLocations, nmin = 10, nmax = 30
         ## mask out values outside physical limits:
         for(i in 1:nsim){
           rk@data[,i] <- ifelse(rk@data[,i] > zmax, zmax, ifelse(rk@data[,i] < zmin, zmin, rk@data[,i]))
-          if(object@regModel$family$family == "poisson"){
-            rk@data[,i] <- as.integer(round(rk@data[,i], 0))
+          if(any(class(object@regModel)=="glm")){
+            if(object@regModel$family$family == "poisson"){
+              rk@data[,i] <- as.integer(round(rk@data[,i], 0))
+            }
           }
         }    
       }
@@ -199,8 +209,15 @@ predict.gstatModel <- function(object, predictionLocations, nmin = 10, nmax = 30
         ## [http://en.wikipedia.org/wiki/Confidence_and_prediction_bands]
         predictionLocations@data[,"fit.var"] <- rp[["se.fit"]]^2
       } else {
-        ## TH: Prediction error for rpart / randomForest (unknown?):
-        predictionLocations@data[,"fit.var"] <- 0
+        if(any(class(object@regModel)=="quantregForest")){     
+          ## TH: Prediction error for randomForest
+          message("Prediction error for 'randomForest' model estimated using the 'quantreg' package.")
+          var.rf <- predict(object@regModel, predictionLocations@data[,covs], quantiles=c((1-.682)/2, 1-(1-.682)/2))
+          ## TH: this assumes Normal distribution! [https://en.wikipedia.org/wiki/File:Standard_deviation_diagram.svg]
+          predictionLocations@data[,"fit.var"] <- ((var.rf[,1] - var.rf[,2])/2)^2
+        } else {
+          predictionLocations@data[,"fit.var"] <- 0
+        } 
       }
 
       ## predict the residuals:
@@ -254,8 +271,10 @@ predict.gstatModel <- function(object, predictionLocations, nmin = 10, nmax = 30
           rk@data[,paste(variable, "svar", sep=".")] <- rk@data[,"var1.var"] / var(observed@data[,variable], na.rm=TRUE)  
           ## mask out values outside the physical limits:
           rk@data[,variable] <- ifelse(rk$var1.pred > zmax, zmax, ifelse(rk$var1.pred < zmin, zmin, rk$var1.pred))
-          if(object@regModel$family$family == "poisson"){
-            rk@data[,variable] <- as.integer(round(rk@data[,variable], 0))
+          if(any(class(object@regModel)=="glm")){
+            if(object@regModel$family$family == "poisson"){
+              rk@data[,variable] <- as.integer(round(rk@data[,variable], 0))
+            }
           }
 
           if(nfold>0){
@@ -294,9 +313,11 @@ predict.gstatModel <- function(object, predictionLocations, nmin = 10, nmax = 30
           rk@data[,i] <- xsim + rk@data[,i]
           ## TH: this does not costs so much time to compute, but it assumes that the trend and residuals are independent!        
           rk@data[,i] <- ifelse(rk@data[,i] > zmax, zmax, ifelse(rk@data[,i] < zmin, zmin, rk@data[,i]))
+          if(any(class(object@regModel)=="glm")){
            if(object@regModel$family$family == "poisson"){
              rk@data[,i] <- as.integer(round(rk@data[,i], 0))
            }
+          }
         }
         }
       }
